@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "ActivityMonitor.hh"
@@ -32,15 +32,15 @@
 #include <stdio.h>
 #include <sys/types.h>
 #if STDC_HEADERS
-# include <stdlib.h>
-# include <stddef.h>
-#else
-# if HAVE_STDLIB_H
 #  include <stdlib.h>
-# endif
+#  include <stddef.h>
+#else
+#  if HAVE_STDLIB_H
+#    include <stdlib.h>
+#  endif
 #endif
 #if HAVE_UNISTD_H
-# include <unistd.h>
+#  include <unistd.h>
 #endif
 
 #include "IInputMonitor.hh"
@@ -49,13 +49,11 @@
 using namespace std;
 
 //! Constructor.
-ActivityMonitor::ActivityMonitor() :
-  activity_state(ACTIVITY_IDLE),
-  prev_x(-10),
-  prev_y(-10),
-  button_is_pressed(false),
-  sensitivity(3),
-  listener(NULL)
+ActivityMonitor::ActivityMonitor()
+  : prev_x(-10)
+  , prev_y(-10)
+  , button_is_pressed(false)
+  , listener(NULL)
 {
   TRACE_ENTER("ActivityMonitor::ActivityMonitor");
 
@@ -74,7 +72,6 @@ ActivityMonitor::ActivityMonitor() :
   TRACE_EXIT();
 }
 
-
 //! Destructor.
 ActivityMonitor::~ActivityMonitor()
 {
@@ -85,7 +82,6 @@ ActivityMonitor::~ActivityMonitor()
   TRACE_EXIT();
 }
 
-
 //! Terminates the monitor.
 void
 ActivityMonitor::terminate()
@@ -100,7 +96,6 @@ ActivityMonitor::terminate()
   TRACE_EXIT();
 }
 
-
 //! Suspends the activity monitoring.
 void
 ActivityMonitor::suspend()
@@ -109,10 +104,10 @@ ActivityMonitor::suspend()
   lock.lock();
   activity_state = ACTIVITY_SUSPENDED;
   lock.unlock();
+  activity_state.publish();
   TRACE_RETURN(activity_state);
 }
 
-
 //! Resumes the activity monitoring.
 void
 ActivityMonitor::resume()
@@ -121,10 +116,10 @@ ActivityMonitor::resume()
   lock.lock();
   activity_state = ACTIVITY_IDLE;
   lock.unlock();
+  activity_state.publish();
   TRACE_RETURN(activity_state);
 }
 
-
 //! Forces state te be idle.
 void
 ActivityMonitor::force_idle()
@@ -137,10 +132,10 @@ ActivityMonitor::force_idle()
       last_action_time = 0;
     }
   lock.unlock();
+  activity_state.publish();
   TRACE_RETURN(activity_state);
 }
 
-
 //! Returns the current state
 ActivityState
 ActivityMonitor::get_current_state()
@@ -154,9 +149,8 @@ ActivityMonitor::get_current_state()
       gint64 now = g_get_real_time();
       gint64 tv = now - last_action_time;
 
-      TRACE_MSG("Active: "
-                << (tv / G_USEC_PER_SEC)  << "." << tv<< " "
-                << (idle_threshold / G_USEC_PER_SEC) << " " << idle_threshold);
+      TRACE_MSG("Active: " << (tv / G_USEC_PER_SEC) << "." << tv << " " << (idle_threshold / G_USEC_PER_SEC) << " "
+                           << idle_threshold);
       if (tv > idle_threshold)
         {
           // No longer active.
@@ -165,18 +159,18 @@ ActivityMonitor::get_current_state()
     }
 
   lock.unlock();
+  activity_state.publish();
   TRACE_RETURN(activity_state);
   return activity_state;
 }
 
-
-
 //! Sets the operation parameters.
 void
 ActivityMonitor::set_parameters(int noise, int activity, int idle, int sensitivity)
 {
   noise_threshold = noise * 1000;
-  activity_threshold = activity * 1000;;
+  activity_threshold = activity * 1000;
+  ;
   idle_threshold = idle * 1000;
 
   this->sensitivity = sensitivity;
@@ -185,25 +179,23 @@ ActivityMonitor::set_parameters(int noise, int activity, int idle, int sensitivi
   activity_state = ACTIVITY_IDLE;
 }
 
-
-
 //! Sets the operation parameters.
 void
 ActivityMonitor::get_parameters(int &noise, int &activity, int &idle, int &sensitivity)
 {
   noise = noise_threshold / 1000;
-  activity = activity_threshold /  1000;
+  activity = activity_threshold / 1000;
   idle = idle_threshold / 1000;
   sensitivity = this->sensitivity;
 }
 
-
 //! Shifts the internal time (after system clock has been set)
 void
 ActivityMonitor::shift_time(int delta)
 {
   gint64 d = delta * G_USEC_PER_SEC;
 
+  Diagnostics::instance().log("activity_monitor: shift");
   lock.lock();
 
   if (last_action_time != 0)
@@ -215,7 +207,6 @@ ActivityMonitor::shift_time(int delta)
   lock.unlock();
 }
 
-
 //! Sets the callback listener.
 void
 ActivityMonitor::set_listener(ActivityMonitorListener *l)
@@ -225,7 +216,6 @@ ActivityMonitor::set_listener(ActivityMonitorListener *l)
   lock.unlock();
 }
 
-
 //! Activity is reported by the input monitor.
 void
 ActivityMonitor::action_notify()
@@ -261,7 +251,7 @@ ActivityMonitor::action_notify()
           }
         else
           {
-            tv =  now - first_action_time;
+            tv = now - first_action_time;
             if (tv >= activity_threshold)
               {
                 activity_state = ACTIVITY_ACTIVE;
@@ -279,7 +269,6 @@ ActivityMonitor::action_notify()
   call_listener();
 }
 
-
 //! Mouse activity is reported by the input monitor.
 void
 ActivityMonitor::mouse_notify(int x, int y, int wheel_delta)
@@ -290,15 +279,13 @@ ActivityMonitor::mouse_notify(int x, int y, int wheel_delta)
   prev_x = x;
   prev_y = y;
 
-  if (abs(delta_x) >= sensitivity || abs(delta_y) >= sensitivity
-      || wheel_delta != 0 || button_is_pressed)
+  if (abs(delta_x) >= sensitivity || abs(delta_y) >= sensitivity || wheel_delta != 0 || button_is_pressed)
     {
       action_notify();
     }
   lock.unlock();
 }
 
-
 //! Mouse button activity is reported by the input monitor.
 void
 ActivityMonitor::button_notify(bool is_press)
@@ -315,7 +302,6 @@ ActivityMonitor::button_notify(bool is_press)
   lock.unlock();
 }
 
-
 //! Keyboard activity is reported by the input monitor.
 void
 ActivityMonitor::keyboard_notify(bool repeat)
@@ -327,7 +313,6 @@ ActivityMonitor::keyboard_notify(bool repeat)
   lock.unlock();
 }
 
-
 //! Calls the callback listener.
 void
 ActivityMonitor::call_listener()
