@@ -28,7 +28,6 @@ Thread::Thread(Runnable *runnable, bool autodelete)
   this->autodelete = autodelete;
 }
 
-
 Thread::Thread(bool autodelete)
 {
   thread_handle = NULL;
@@ -41,7 +40,6 @@ Thread::~Thread()
   wait();
 }
 
-
 void
 Thread::start()
 {
@@ -50,15 +48,9 @@ Thread::start()
       GError *error = NULL;
 
 #if GLIB_CHECK_VERSION(2, 31, 18)
-      thread_handle = g_thread_try_new("workrave",
-                                       thread_handler,
-                                       this,
-                                       &error);
+      thread_handle = g_thread_try_new("workrave", thread_handler, this, &error);
 #else
-      thread_handle = g_thread_create(thread_handler,
-                                      this,
-                                      TRUE,
-                                      &error);
+      thread_handle = g_thread_create(thread_handler, this, TRUE, &error);
 #endif
       if (error != NULL)
         {
@@ -67,7 +59,6 @@ Thread::start()
     }
 }
 
-
 void
 Thread::wait()
 {
@@ -78,7 +69,6 @@ Thread::wait()
     }
 }
 
-
 void
 Thread::run()
 {
@@ -95,20 +85,18 @@ Thread::internal_run()
   thread_handle = NULL;
 }
 
-
 gpointer
 Thread::thread_handler(gpointer data)
 {
-  Thread *t = (Thread *) data;
+  Thread *t = (Thread *)data;
   if (t != NULL)
     {
       t->internal_run();
       if (t->autodelete)
-         {
-           delete t;
-         }
+        {
+          delete t;
+        }
     }
 
   return 0;
 }
-
