@@ -22,7 +22,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include <stdio.h>
@@ -36,15 +36,15 @@
 #include <io.h>
 
 #ifndef _O_APPEND
-#define _O_APPEND       0x0008
+#  define _O_APPEND 0x0008
 #endif
 #ifndef _O_TEXT
-#define _O_TEXT         0x4000
+#  define _O_TEXT 0x4000
 #endif
 
-#ifdef PLATFORM_OS_WIN32_NATIVE
-#define snprintf _snprintf
-#define snwprintf _snwprintf
+#ifdef PLATFORM_OS_WINDOWS_NATIVE
+#  define snprintf _snprintf
+#  define snwprintf _snwprintf
 #endif
 
 static void unwind_stack(FILE *log, HANDLE process, PCONTEXT context);
@@ -52,25 +52,24 @@ static void dump_registers(FILE *log, PCONTEXT context);
 static void dump_registry(FILE *log, HKEY key, char *name);
 /* static void print_module_list(FILE *log); */
 
-static
-DWORD GetModuleBase(DWORD dwAddress)
+static DWORD
+GetModuleBase(DWORD dwAddress)
 {
   MEMORY_BASIC_INFORMATION Buffer;
 
-  return VirtualQuery((LPCVOID) dwAddress, &Buffer, sizeof(Buffer)) ? (DWORD) Buffer.AllocationBase : 0;
+  return VirtualQuery((LPCVOID)dwAddress, &Buffer, sizeof(Buffer)) ? (DWORD)Buffer.AllocationBase : 0;
 }
 
-#ifndef PLATFORM_OS_WIN32_NATIVE
-static EXCEPTION_DISPOSITION __cdecl
-double_exception_handler(struct _EXCEPTION_RECORD *exception_record,
-                         void *establisher_frame,
-                         struct _CONTEXT *context_record,
-                         void *dispatcher_context)
+#ifndef PLATFORM_OS_WINDOWS_NATIVE
+static EXCEPTION_DISPOSITION __cdecl double_exception_handler(struct _EXCEPTION_RECORD *exception_record,
+                                                              void *establisher_frame,
+                                                              struct _CONTEXT *context_record,
+                                                              void *dispatcher_context)
 {
-  (void) exception_record;
-  (void) establisher_frame;
-  (void) context_record;
-  (void) dispatcher_context;
+  (void)exception_record;
+  (void)establisher_frame;
+  (void)context_record;
+  (void)dispatcher_context;
 
   MessageBox(NULL,
              (LPCSTR)"Workrave has unexpectedly crashed and failed to create a crash "
@@ -82,33 +81,34 @@ double_exception_handler(struct _EXCEPTION_RECORD *exception_record,
 }
 #endif
 
-EXCEPTION_DISPOSITION __cdecl
-exception_handler(struct _EXCEPTION_RECORD *exception_record,
-                  void *establisher_frame,
-                  struct _CONTEXT *context_record,
-                  void *dispatcher_context)
+EXCEPTION_DISPOSITION __cdecl exception_handler(struct _EXCEPTION_RECORD *exception_record,
+                                                void *establisher_frame,
+                                                struct _CONTEXT *context_record,
+                                                void *dispatcher_context)
 {
   char crash_log_name[MAX_PATH];
   char crash_text[1024];
   TCHAR szModule[MAX_PATH];
   HMODULE hModule;
-/*
- Modified for Unicode >= WinNT. No UnicoWS check for Me/98/95.
- jay satiro, workrave project, july 2007
-*/
-  WCHAR env_var[ 20 ] = { '\0', };
+  /*
+   Modified for Unicode >= WinNT. No UnicoWS check for Me/98/95.
+   jay satiro, workrave project, july 2007
+  */
+  WCHAR env_var[20] = {
+    '\0',
+  };
   WCHAR crashlog[] = L"\\workrave-crashlog.txt";
   WCHAR *wbuffer = NULL;
-  WCHAR *p_wbuffer = NULL;  FILE *log;
-  DWORD ( WINAPI *GetEnvironmentVariableW ) ( LPCWSTR, LPWSTR, DWORD );
-  HANDLE ( WINAPI *CreateFileW ) ( LPCWSTR, DWORD, DWORD,
-  LPSECURITY_ATTRIBUTES, DWORD, DWORD, HANDLE );
+  WCHAR *p_wbuffer = NULL;
+  FILE *log;
+  DWORD(WINAPI * GetEnvironmentVariableW)(LPCWSTR, LPWSTR, DWORD);
+  HANDLE(WINAPI * CreateFileW)(LPCWSTR, DWORD, DWORD, LPSECURITY_ATTRIBUTES, DWORD, DWORD, HANDLE);
   SYSTEMTIME SystemTime;
 
-  (void) establisher_frame;
-  (void) dispatcher_context;
+  (void)establisher_frame;
+  (void)dispatcher_context;
 
-#ifdef PLATFORM_OS_WIN32_NATIVE
+#ifdef PLATFORM_OS_WINDOWS_NATIVE
   // FIXME: win32
 #else
   __try1(double_exception_handler);
@@ -116,119 +116,107 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
 
   harpoon_unblock_input();
 
+  GetEnvironmentVariableW =
+    (DWORD(WINAPI *)(LPCWSTR, LPWSTR, DWORD))GetProcAddress(GetModuleHandleA("kernel32.dll"), "GetEnvironmentVariableW");
+  CreateFileW = (HANDLE(WINAPI *)(LPCWSTR, DWORD, DWORD, LPSECURITY_ATTRIBUTES, DWORD, DWORD, HANDLE))GetProcAddress(
+    GetModuleHandleA("kernel32.dll"), "CreateFileW");
 
-
-
-  GetEnvironmentVariableW = ( DWORD ( WINAPI * ) ( LPCWSTR, LPWSTR, DWORD ) )
-    GetProcAddress( GetModuleHandleA( "kernel32.dll" ), "GetEnvironmentVariableW" );
-  CreateFileW = ( HANDLE ( WINAPI * ) ( LPCWSTR, DWORD, DWORD,
-    LPSECURITY_ATTRIBUTES, DWORD, DWORD, HANDLE ) )
-      GetProcAddress( GetModuleHandleA( "kernel32.dll" ), "CreateFileW" );
-
-  if( GetEnvironmentVariableW && CreateFileW )
-  // >= WinNT
+  if (GetEnvironmentVariableW && CreateFileW)
+    // >= WinNT
     {
       HANDLE handle;
       DWORD bufsize, ret;
       int fd = 0;
 
-      wcsncpy( env_var, L"APPDATA", 19 );
-      env_var[ 19 ] = '\0';
-      bufsize = ( *GetEnvironmentVariableW ) ( env_var, NULL, 0 );
+      wcsncpy(env_var, L"APPDATA", 19);
+      env_var[19] = '\0';
+      bufsize = (*GetEnvironmentVariableW)(env_var, NULL, 0);
       // bufsize is size in wide chars, including null
 
-      if( !bufsize )
-      // If %appdata% is unsuitable, try temp:
-      {
-          wcsncpy( env_var, L"TEMP", 19 );
-          env_var[ 19 ] = '\0';
-          bufsize = ( *GetEnvironmentVariableW ) ( env_var, NULL, 0 );
-      }
+      if (!bufsize)
+        // If %appdata% is unsuitable, try temp:
+        {
+          wcsncpy(env_var, L"TEMP", 19);
+          env_var[19] = '\0';
+          bufsize = (*GetEnvironmentVariableW)(env_var, NULL, 0);
+        }
 
       ret = 0;
       wbuffer = NULL;
 
-      if( bufsize )
+      if (bufsize)
         {
           // We will need room for \\?\ so add 4
-          if( (wbuffer = (WCHAR *)calloc( 4 + bufsize + wcslen( crashlog ), sizeof( WCHAR ) ) ) != NULL)
+          if ((wbuffer = (WCHAR *)calloc(4 + bufsize + wcslen(crashlog), sizeof(WCHAR))) != NULL)
             {
-              wcscpy( wbuffer, L"\\\\?\\" );
+              wcscpy(wbuffer, L"\\\\?\\");
               p_wbuffer = wbuffer + 4;
-              ret = ( *GetEnvironmentVariableW ) ( env_var, p_wbuffer, bufsize );
+              ret = (*GetEnvironmentVariableW)(env_var, p_wbuffer, bufsize);
             }
         }
 
-      if( !ret )
-      // Environment unsuitable, notify & terminate.
+      if (!ret)
+        // Environment unsuitable, notify & terminate.
         {
-          free( wbuffer );
-          snprintf(crash_text, 1023,
-            "Workrave has unexpectedly crashed. The environment is "
-            "unsuitable to create a crash log. Please file a bug report:\n"
-            "http://issues.workrave.org/\n"
-            "Thanks.");
-          MessageBoxA( NULL, crash_text, "Exception", MB_OK );
+          free(wbuffer);
+          snprintf(crash_text,
+                   1023,
+                   "Workrave has unexpectedly crashed. The environment is "
+                   "unsuitable to create a crash log. Please file a bug report:\n"
+                   "http://issues.workrave.org/\n"
+                   "Thanks.");
+          MessageBoxA(NULL, crash_text, "Exception", MB_OK);
 
-#ifdef PLATFORM_OS_WIN32_NATIVE
-  // FIXME: win32
+#ifdef PLATFORM_OS_WINDOWS_NATIVE
+          // FIXME: win32
 #else
           __except1;
 #endif
-          exit( 1 );
+          exit(1);
         }
 
-      //last wchar
+      // last wchar
       p_wbuffer = wbuffer + wcslen(wbuffer) - 1;
 
-      while( *p_wbuffer == L'\\' )
-      // remove trailing slashes
+      while (*p_wbuffer == L'\\')
+        // remove trailing slashes
         {
           *p_wbuffer-- = L'\0';
         }
 
       // append filename to end of string
-      wcscpy( ++p_wbuffer, crashlog );
-
+      wcscpy(++p_wbuffer, crashlog);
 
       // compare first wchar of returned environment string
-      if( wbuffer[ 4 ] == L'\\' )
-      /*
-      If possible network path, don't include literal \\?\
-      \\?\\\1.2.3.4\workrave-crashlog.txt should be
-      \\1.2.3.4\workrave-crashlog.txt
-      */
-          p_wbuffer = wbuffer + 4;
+      if (wbuffer[4] == L'\\')
+        /*
+        If possible network path, don't include literal \\?\
+        \\?\\\1.2.3.4\workrave-crashlog.txt should be
+        \\1.2.3.4\workrave-crashlog.txt
+        */
+        p_wbuffer = wbuffer + 4;
       else
-      // Point to start of wbuffer:
-          p_wbuffer = wbuffer;
+        // Point to start of wbuffer:
+        p_wbuffer = wbuffer;
 
+      handle =
+        (*CreateFileW)(p_wbuffer, GENERIC_READ | GENERIC_WRITE, FILE_SHARE_READ, NULL, CREATE_ALWAYS, FILE_ATTRIBUTE_NORMAL, NULL);
 
-      handle = ( *CreateFileW ) (
-          p_wbuffer,
-          GENERIC_READ | GENERIC_WRITE,
-          FILE_SHARE_READ,
-          NULL,
-          CREATE_ALWAYS,
-          FILE_ATTRIBUTE_NORMAL,
-          NULL
-        );
-
-      fd = _open_osfhandle( (intptr_t) handle, _O_APPEND | _O_TEXT );
-      log = _fdopen( fd, "w" );
+      fd = _open_osfhandle((intptr_t)handle, _O_APPEND | _O_TEXT);
+      log = _fdopen(fd, "w");
     }
-  else  // if( GetVersion() & (DWORD) 0x80000000 )
-  // Windows Me/98/95
+  else // if( GetVersion() & (DWORD) 0x80000000 )
+       // Windows Me/98/95
     {
       char *s = NULL;
       GetModuleFileName(GetModuleHandle(NULL), crash_log_name, sizeof(crash_log_name));
       // crash_log_name == c:\program files\workrave\lib\workrave.exe
       s = strrchr(crash_log_name, '\\');
-      assert (s);
+      assert(s);
       *s = '\0';
       // crash_log_name == c:\program files\workrave\lib
       s = strrchr(crash_log_name, '\\');
-      assert (s);
+      assert(s);
       *s = '\0';
       // crash_log_name == c:\program files\workrave
       strcat(crash_log_name, "\\workrave-crashlog.txt");
@@ -236,26 +224,27 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
       log = fopen(crash_log_name, "w");
     }
 
-    if( log == NULL )
-      // workrave-crashlog.txt wasn't created.
-      {
-        snprintf(crash_text, 1023,
-          "Workrave has unexpectedly crashed. An attempt to create "
-          "a crashlog has failed. Please file a bug report:\n"
-          "http://issues.workrave.org/\n"
-          "Thanks.");
-        MessageBoxA( NULL, crash_text, "Exception", MB_OK );
-#ifdef PLATFORM_OS_WIN32_NATIVE
-  // FIXME: win32
+  if (log == NULL)
+    // workrave-crashlog.txt wasn't created.
+    {
+      snprintf(crash_text,
+               1023,
+               "Workrave has unexpectedly crashed. An attempt to create "
+               "a crashlog has failed. Please file a bug report:\n"
+               "http://issues.workrave.org/\n"
+               "Thanks.");
+      MessageBoxA(NULL, crash_text, "Exception", MB_OK);
+#ifdef PLATFORM_OS_WINDOWS_NATIVE
+      // FIXME: win32
 #else
-        __except1;
+      __except1;
 #endif
-        exit( 1 );
-      }
-
+      exit(1);
+    }
 
   GetLocalTime(&SystemTime);
-  fprintf(log, "Crash log created on %02d/%02d/%04d at %02d:%02d:%02d.\n\n",
+  fprintf(log,
+          "Crash log created on %02d/%02d/%04d at %02d:%02d:%02d.\n\n",
           SystemTime.wDay,
           SystemTime.wMonth,
           SystemTime.wYear,
@@ -266,7 +255,8 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
   fprintf(log, "version = %s\n", PACKAGE_VERSION);
   fprintf(log, "compile date = %s\n", __DATE__);
   fprintf(log, "compile time = %s\n", __TIME__);
-  fprintf(log, "features = "
+  fprintf(log,
+          "features = "
 #ifdef HAVE_DISTRIBUTION
           "DISTRIBUTION "
 #endif
@@ -291,32 +281,30 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
 #ifndef NDEBUG
           "DEBUG "
 #endif
-          "\n"
-          );
+          "\n");
 
-// write locale info:
+  // write locale info:
   char *buffer = NULL;
-  int bufsize =
-      GetLocaleInfoA( LOCALE_USER_DEFAULT, LOCALE_SENGLANGUAGE, buffer, 0);
+  int bufsize = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SENGLANGUAGE, buffer, 0);
 
-  if( bufsize )
-      buffer = (char *)calloc( bufsize + 1, 1 );
+  if (bufsize)
+    buffer = (char *)calloc(bufsize + 1, 1);
 
-  if( buffer )
+  if (buffer)
     {
-      GetLocaleInfoA( LOCALE_USER_DEFAULT, LOCALE_SENGLANGUAGE, buffer, bufsize);
-      buffer[ bufsize ] = '\0';
-      fprintf( log, "locale = %s\n", buffer );
-      free( buffer );
+      GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SENGLANGUAGE, buffer, bufsize);
+      buffer[bufsize] = '\0';
+      fprintf(log, "locale = %s\n", buffer);
+      free(buffer);
     }
 
   fprintf(log, "\n\n");
-  fprintf(log, "code = %x\n", (int) exception_record->ExceptionCode);
-  fprintf(log, "flags = %x\n", (int) exception_record->ExceptionFlags);
-  fprintf(log, "address = %x\n", (int) exception_record->ExceptionAddress);
-  fprintf(log, "params = %d\n", (int) exception_record->NumberParameters);
+  fprintf(log, "code = %x\n", (int)exception_record->ExceptionCode);
+  fprintf(log, "flags = %x\n", (int)exception_record->ExceptionFlags);
+  fprintf(log, "address = %x\n", (int)exception_record->ExceptionAddress);
+  fprintf(log, "params = %d\n", (int)exception_record->NumberParameters);
 
-  fprintf(log, "%s caused ",  GetModuleFileName(NULL, szModule, MAX_PATH) ? szModule : "Application");
+  fprintf(log, "%s caused ", GetModuleFileName(NULL, szModule, MAX_PATH) ? szModule : "Application");
   switch (exception_record->ExceptionCode)
     {
     case EXCEPTION_ACCESS_VIOLATION:
@@ -436,14 +424,17 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
       break;
     }
 
-  fprintf(log, " at location %08x", (int) exception_record->ExceptionAddress);
-  hModule = (HMODULE) GetModuleBase((DWORD) exception_record->ExceptionAddress);
+  fprintf(log, " at location %08x", (int)exception_record->ExceptionAddress);
+  hModule = (HMODULE)GetModuleBase((DWORD)exception_record->ExceptionAddress);
   if ((hModule != NULL && GetModuleFileName(hModule, szModule, sizeof(szModule))))
     fprintf(log, " in module %s", szModule);
 
   // If the exception was an access violation, print out some additional information, to the error log and the debugger.
-  if(exception_record->ExceptionCode == EXCEPTION_ACCESS_VIOLATION && exception_record->NumberParameters >= 2)
-    fprintf(log, " %s location %08x\n\n", exception_record->ExceptionInformation[0] ? "writing to" : "reading from", exception_record->ExceptionInformation[1]);
+  if (exception_record->ExceptionCode == EXCEPTION_ACCESS_VIOLATION && exception_record->NumberParameters >= 2)
+    fprintf(log,
+            " %s location %08x\n\n",
+            exception_record->ExceptionInformation[0] ? "writing to" : "reading from",
+            exception_record->ExceptionInformation[1]);
 
   DWORD pid = GetCurrentProcessId();
   HANDLE process = OpenProcess(PROCESS_ALL_ACCESS, TRUE, pid);
@@ -458,59 +449,58 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
 
   fclose(log);
 
-  if( GetEnvironmentVariableW && CreateFileW )
-  // >= WinNT
+  if (GetEnvironmentVariableW && CreateFileW)
+    // >= WinNT
     {
-      WCHAR *one =
-          L"Workrave has unexpectedly crashed. A crash log has been saved to:\n";
+      WCHAR *one = L"Workrave has unexpectedly crashed. A crash log has been saved to:\n";
 
       WCHAR *two =
-          L"\nPlease file a bug report: http://issues.workrave.org/\n"
-          L"Thanks.";
+        L"\nPlease file a bug report: http://issues.workrave.org/\n"
+        L"Thanks.";
 
-      WCHAR *nomem =
-          L"Workrave is out of memory!";
+      WCHAR *nomem = L"Workrave is out of memory!";
 
-      int size = wcslen( one ) + wcslen( p_wbuffer ) + wcslen( two ) + 1;
+      int size = wcslen(one) + wcslen(p_wbuffer) + wcslen(two) + 1;
 
-      WCHAR *message = (WCHAR *)calloc( size, sizeof( WCHAR ) );
-      if( !message )
-      // Low memory...
+      WCHAR *message = (WCHAR *)calloc(size, sizeof(WCHAR));
+      if (!message)
+        // Low memory...
         {
           // % + % + null = 3 extra
-          size = wcslen( one ) + wcslen( env_var ) + wcslen( crashlog ) + wcslen( two ) + 3;
-          message = (WCHAR *)calloc( size, sizeof( WCHAR ) );
-          if( message )
+          size = wcslen(one) + wcslen(env_var) + wcslen(crashlog) + wcslen(two) + 3;
+          message = (WCHAR *)calloc(size, sizeof(WCHAR));
+          if (message)
             {
-              snwprintf( message, size - 1, L"%ws%%%ws%%%ws%ws",
-                  one, env_var, crashlog, two );
-              message[ size - 1 ] = L'\0';
+              snwprintf(message, size - 1, L"%ws%%%ws%%%ws%ws", one, env_var, crashlog, two);
+              message[size - 1] = L'\0';
             }
-           else
-           // No memory...
-              message = nomem;
+          else
+            // No memory...
+            message = nomem;
         }
       else
-      // A buffer was allocated with enough memory to hold p_wbuffer
+        // A buffer was allocated with enough memory to hold p_wbuffer
         {
-          snwprintf( message, size - 1, L"%ws%ws%ws", one, p_wbuffer, two );
-          message[ size - 1 ] = L'\0';
+          snwprintf(message, size - 1, L"%ws%ws%ws", one, p_wbuffer, two);
+          message[size - 1] = L'\0';
         }
 
-      MessageBoxW( NULL, message, L"Exception", MB_OK );
+      MessageBoxW(NULL, message, L"Exception", MB_OK);
     }
   else
     {
-      snprintf(crash_text, 1023,
-        "Workrave has unexpectedly crashed. A crash log has been saved to "
-        "%s. Please mail this file to crashes@workrave.org or "
-        "file a bugreport at: http://issues.workrave.org/. "
-        "Thanks.", crash_log_name);
+      snprintf(crash_text,
+               1023,
+               "Workrave has unexpectedly crashed. A crash log has been saved to "
+               "%s. Please mail this file to crashes@workrave.org or "
+               "file a bugreport at: http://issues.workrave.org/. "
+               "Thanks.",
+               crash_log_name);
       MessageBoxA(NULL, crash_text, "Exception", MB_OK);
     }
 
-#ifdef PLATFORM_OS_WIN32_NATIVE
-  // FIXME: win32
+#ifdef PLATFORM_OS_WINDOWS_NATIVE
+    // FIXME: win32
 #else
   __except1;
 #endif
@@ -518,9 +508,8 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
   exit(1);
 }
 
-
-static
-BOOL WINAPI stack_walk(HANDLE process, LPSTACKFRAME stack_frame, PCONTEXT context_record)
+static BOOL WINAPI
+stack_walk(HANDLE process, LPSTACKFRAME stack_frame, PCONTEXT context_record)
 {
   if (!stack_frame->Reserved[0])
     {
@@ -535,25 +524,29 @@ BOOL WINAPI stack_walk(HANDLE process, LPSTACKFRAME stack_frame, PCONTEXT contex
 
       stack_frame->AddrReturn.Mode = AddrModeFlat;
       if (!ReadProcessMemory(process,
-                             (LPCVOID) (stack_frame->AddrFrame.Offset + sizeof(DWORD)),
-                             &stack_frame->AddrReturn.Offset, sizeof(DWORD), NULL))
+                             (LPCVOID)(stack_frame->AddrFrame.Offset + sizeof(DWORD)),
+                             &stack_frame->AddrReturn.Offset,
+                             sizeof(DWORD),
+                             NULL))
         return FALSE;
     }
   else
     {
       stack_frame->AddrPC.Offset = stack_frame->AddrReturn.Offset;
 
-      if (!ReadProcessMemory(process, (LPCVOID) stack_frame->AddrFrame.Offset,
-                            &stack_frame->AddrFrame.Offset, sizeof(DWORD), NULL))
+      if (!ReadProcessMemory(process, (LPCVOID)stack_frame->AddrFrame.Offset, &stack_frame->AddrFrame.Offset, sizeof(DWORD), NULL))
         return FALSE;
 
-      if (!ReadProcessMemory(process, (LPCVOID) (stack_frame->AddrFrame.Offset + sizeof(DWORD)),
-                             &stack_frame->AddrReturn.Offset, sizeof(DWORD), NULL))
+      if (!ReadProcessMemory(process,
+                             (LPCVOID)(stack_frame->AddrFrame.Offset + sizeof(DWORD)),
+                             &stack_frame->AddrReturn.Offset,
+                             sizeof(DWORD),
+                             NULL))
         return FALSE;
     }
 
-  ReadProcessMemory(process, (LPCVOID) (stack_frame->AddrFrame.Offset + 2*sizeof(DWORD)),
-                    stack_frame->Params, sizeof(stack_frame->Params), NULL);
+  ReadProcessMemory(
+    process, (LPCVOID)(stack_frame->AddrFrame.Offset + 2 * sizeof(DWORD)), stack_frame->Params, sizeof(stack_frame->Params), NULL);
 
   return TRUE;
 }
@@ -561,17 +554,17 @@ BOOL WINAPI stack_walk(HANDLE process, LPSTACKFRAME stack_frame, PCONTEXT contex
 static void
 unwind_stack(FILE *log, HANDLE process, PCONTEXT context)
 {
-  STACKFRAME          sf;
+  STACKFRAME sf;
 
   fprintf(log, "Stack trace:\n\n");
 
-  ZeroMemory(&sf,  sizeof(STACKFRAME));
-  sf.AddrPC.Offset    = context->Eip;
-  sf.AddrPC.Mode      = AddrModeFlat;
+  ZeroMemory(&sf, sizeof(STACKFRAME));
+  sf.AddrPC.Offset = context->Eip;
+  sf.AddrPC.Mode = AddrModeFlat;
   sf.AddrStack.Offset = context->Esp;
-  sf.AddrStack.Mode   = AddrModeFlat;
+  sf.AddrStack.Mode = AddrModeFlat;
   sf.AddrFrame.Offset = context->Ebp;
-  sf.AddrFrame.Mode   = AddrModeFlat;
+  sf.AddrFrame.Mode = AddrModeFlat;
 
   fprintf(log, "PC        Frame     Ret\n");
 
@@ -583,10 +576,7 @@ unwind_stack(FILE *log, HANDLE process, PCONTEXT context)
       if (sf.AddrFrame.Offset == 0)
         break;
 
-      fprintf(log, "%08X  %08X  %08X\n",
-              (int) sf.AddrPC.Offset,
-              (int) sf.AddrFrame.Offset,
-              (int) sf.AddrReturn.Offset);
+      fprintf(log, "%08X  %08X  %08X\n", (int)sf.AddrPC.Offset, (int)sf.AddrFrame.Offset, (int)sf.AddrReturn.Offset);
     }
 }
 
@@ -610,7 +600,8 @@ print_module_info(FILE *log, HMODULE mod)
       CloseHandle(file);
     }
 
-  fprintf(log, " %-20s handle: %p date: %d-%.2d-%.2d %.2d:%.2d:%.2d\n",
+  fprintf(log,
+          " %-20s handle: %p date: %d-%.2d-%.2d %.2d:%.2d:%.2d\n",
           buffer,
           mod,
           file_time.wYear,
@@ -618,21 +609,20 @@ print_module_info(FILE *log, HMODULE mod)
           file_time.wDay,
           file_time.wHour,
           file_time.wMinute,
-          file_time.wSecond
-          );
+          file_time.wSecond);
 }
 
 void
 print_module_list(FILE *log)
 {
   HMODULE lib;
-  BOOL (WINAPI *EnumProcessModules)(HANDLE, HMODULE*, DWORD, LPDWORD);
+  BOOL(WINAPI * EnumProcessModules)(HANDLE, HMODULE *, DWORD, LPDWORD);
 
   EnumProcessModules = NULL;
   lib = LoadLibrary("psapi.dll");
   if (lib != NULL)
     {
-      EnumProcessModules = (BOOL (WINAPI *)(HANDLE, HMODULE*, DWORD, LPDWORD)) GetProcAddress(lib, "EnumProcessModules");
+      EnumProcessModules = (BOOL(WINAPI *)(HANDLE, HMODULE *, DWORD, LPDWORD))GetProcAddress(lib, "EnumProcessModules");
     }
 
   if (EnumProcessModules != NULL)
@@ -670,36 +660,49 @@ dump_registers(FILE *log, PCONTEXT context)
 
   if (context->ContextFlags & CONTEXT_INTEGER)
     {
-      fprintf(log, "eax=%08lx ebx=%08lx ecx=%08lx edx=%08lx esi=%08lx edi=%08lx\n",
-              context->Eax, context->Ebx, context->Ecx, context->Edx,
-              context->Esi, context->Edi);
+      fprintf(log,
+              "eax=%08lx ebx=%08lx ecx=%08lx edx=%08lx esi=%08lx edi=%08lx\n",
+              context->Eax,
+              context->Ebx,
+              context->Ecx,
+              context->Edx,
+              context->Esi,
+              context->Edi);
     }
 
   if (context->ContextFlags & CONTEXT_CONTROL)
     {
-      fprintf(log, "eip=%08lx esp=%08lx ebp=%08lx iopl=%1lx %s %s %s %s %s %s %s %s %s %s\n",
-              context->Eip, context->Esp, context->Ebp,
-              (context->EFlags >> 12) & 3,  //  IOPL level value
+      fprintf(log,
+              "eip=%08lx esp=%08lx ebp=%08lx iopl=%1lx %s %s %s %s %s %s %s %s %s %s\n",
+              context->Eip,
+              context->Esp,
+              context->Ebp,
+              (context->EFlags >> 12) & 3,                  //  IOPL level value
               context->EFlags & 0x00100000 ? "vip" : "   ", //  VIP (virtual interrupt pending)
               context->EFlags & 0x00080000 ? "vif" : "   ", //  VIF (virtual interrupt flag)
-              context->EFlags & 0x00000800 ? "ov" : "nv", //  VIF (virtual interrupt flag)
-              context->EFlags & 0x00000400 ? "dn" : "up", //  OF (overflow flag)
-              context->EFlags & 0x00000200 ? "ei" : "di", //  IF (interrupt enable flag)
-              context->EFlags & 0x00000080 ? "ng" : "pl", //  SF (sign flag)
-              context->EFlags & 0x00000040 ? "zr" : "nz", //  ZF (zero flag)
-              context->EFlags & 0x00000010 ? "ac" : "na", //  AF (aux carry flag)
-              context->EFlags & 0x00000004 ? "po" : "pe", //  PF (parity flag)
-              context->EFlags & 0x00000001 ? "cy" : "nc"  //  CF (carry flag)
-              );
+              context->EFlags & 0x00000800 ? "ov" : "nv",   //  VIF (virtual interrupt flag)
+              context->EFlags & 0x00000400 ? "dn" : "up",   //  OF (overflow flag)
+              context->EFlags & 0x00000200 ? "ei" : "di",   //  IF (interrupt enable flag)
+              context->EFlags & 0x00000080 ? "ng" : "pl",   //  SF (sign flag)
+              context->EFlags & 0x00000040 ? "zr" : "nz",   //  ZF (zero flag)
+              context->EFlags & 0x00000010 ? "ac" : "na",   //  AF (aux carry flag)
+              context->EFlags & 0x00000004 ? "po" : "pe",   //  PF (parity flag)
+              context->EFlags & 0x00000001 ? "cy" : "nc"    //  CF (carry flag)
+      );
     }
 
   if (context->ContextFlags & CONTEXT_SEGMENTS)
     {
-      fprintf(log, "cs=%04lx  ss=%04lx  ds=%04lx  es=%04lx  fs=%04lx  gs=%04lx",
-              context->SegCs, context->SegSs, context->SegDs, context->SegEs,
-              context->SegFs, context->SegGs);
+      fprintf(log,
+              "cs=%04lx  ss=%04lx  ds=%04lx  es=%04lx  fs=%04lx  gs=%04lx",
+              context->SegCs,
+              context->SegSs,
+              context->SegDs,
+              context->SegEs,
+              context->SegFs,
+              context->SegGs);
 
-      if(context->ContextFlags & CONTEXT_CONTROL)
+      if (context->ContextFlags & CONTEXT_CONTROL)
         {
           fprintf(log, "             efl=%08lx", context->EFlags);
         }
@@ -708,8 +711,7 @@ dump_registers(FILE *log, PCONTEXT context)
     {
       if (context->ContextFlags & CONTEXT_CONTROL)
         {
-          fprintf(log, "                                                                       efl=%08lx",
-                  context->EFlags);
+          fprintf(log, "                                                                       efl=%08lx", context->EFlags);
         }
     }
 
@@ -725,7 +727,7 @@ save_key(FILE *log, HKEY key, char *name)
 
   fprintf(log, "key = %s\n", name);
 
-  for (i = 0; ; i++)
+  for (i = 0;; i++)
     {
       char val[256];
       DWORD val_size = sizeof(val);
@@ -749,7 +751,7 @@ save_key(FILE *log, HKEY key, char *name)
         {
           fprintf(log, "  string data = %s\n", data);
         }
-      else if (type == REG_DWORD && data_size==4)
+      else if (type == REG_DWORD && data_size == 4)
         {
           fprintf(log, "  dword data = %08lx\n", (long)data);
         }
@@ -765,11 +767,10 @@ save_key(FILE *log, HKEY key, char *name)
   strcat(keyname, "\\");
   keyname_len = strlen(keyname);
 
-  for (i = 0; ; i++)
+  for (i = 0;; i++)
     {
       HKEY subkey;
-      LONG rc = RegEnumKey(key, i, keyname + keyname_len,
-                           sizeof(keyname) - keyname_len);
+      LONG rc = RegEnumKey(key, i, keyname + keyname_len, sizeof(keyname) - keyname_len);
 
       if (rc != ERROR_SUCCESS)
         break;
@@ -783,11 +784,10 @@ save_key(FILE *log, HKEY key, char *name)
     }
 }
 
-
 static void
 dump_registry(FILE *log, HKEY key, char *name)
 {
-  (void) key;
+  (void)key;
 
   HKEY handle;
   LONG rc = RegOpenKeyEx(HKEY_CURRENT_USER, name, 0, KEY_ALL_ACCESS, &handle);
