@@ -26,49 +26,49 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #if defined(HAVE_GLIB)
-#include <glib.h>
+#  include <glib.h>
 #endif
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
-#ifdef PLATFORM_OS_OSX
-#include "OSXHelpers.hh"
+#ifdef PLATFORM_OS_MACOS
+#  include "MacOSHelpers.hh"
 #endif
 
 #include <algorithm>
 #include <iostream>
 
 #if defined(HAVE_STRINGS_H)
-#include <strings.h>
+#  include <strings.h>
 #endif
 
 #include "System.hh"
 #include "debug.hh"
 
 #if defined(PLATFORM_OS_UNIX)
-#include "ScreenLockCommandline.hh"
+#  include "ScreenLockCommandline.hh"
 
-#if defined(HAVE_DBUS)
-#include "ScreenLockDBus.hh"
-#include "SystemStateChangeConsolekit.hh"
-#include "SystemStateChangeLogind.hh"
-#include "SystemStateChangeUPower.hh"
-#endif
-#endif //PLATFORM_OS_UNIX
+#  if defined(HAVE_DBUS)
+#    include "ScreenLockDBus.hh"
+#    include "SystemStateChangeConsolekit.hh"
+#    include "SystemStateChangeLogind.hh"
+#    include "SystemStateChangeUPower.hh"
+#  endif
+#endif // PLATFORM_OS_UNIX
 
-#if defined(PLATFORM_OS_WIN32)
-#include "W32Shutdown.hh"
-#include "W32LockScreen.hh"
+#if defined(PLATFORM_OS_WINDOWS)
+#  include "W32Shutdown.hh"
+#  include "W32LockScreen.hh"
 #endif
 
 #if defined(HAVE_UNIX)
-#include <sys/wait.h>
+#  include <sys/wait.h>
 #endif
 
 std::vector<IScreenLockMethod *> System::lock_commands;
@@ -76,29 +76,29 @@ std::vector<ISystemStateChangeMethod *> System::system_state_commands;
 std::vector<System::SystemOperation> System::supported_system_operations;
 
 #if defined(PLATFORM_OS_UNIX) && defined(HAVE_DBUS)
-GDBusConnection* System::session_connection = NULL;
-GDBusConnection* System::system_connection = NULL;
+GDBusConnection *System::session_connection = NULL;
+GDBusConnection *System::system_connection = NULL;
 #endif
 
 #if defined(PLATFORM_OS_UNIX)
-#if defined(HAVE_DBUS)
+#  if defined(HAVE_DBUS)
 void
 System::init_DBus()
 {
   TRACE_ENTER("System::init_dbus()");
-  
+
   GError *error = NULL;
   session_connection = g_bus_get_sync(G_BUS_TYPE_SESSION, NULL, &error);
   if (error != NULL)
     {
-      //it is rare and serious, so report it the user
+      // it is rare and serious, so report it the user
       std::cerr << "Cannot establish connection to the session bus: " << error->message << std::endl;
       g_error_free(error);
       error = NULL;
     }
 
   system_connection = g_bus_get_sync(G_BUS_TYPE_SYSTEM, NULL, &error);
-  if (error != NULL) 
+  if (error != NULL)
     {
       std::cerr << "Cannot establish connection to the system bus: " << error->message << std::endl;
       g_error_free(error);
@@ -108,18 +108,19 @@ System::init_DBus()
   TRACE_EXIT();
 }
 
-
-bool 
-System::add_DBus_lock_cmd(const char *dbus_name, const char *dbus_path, const char *dbus_interface,
-                          const char *dbus_lock_method, const char *dbus_method_to_check_existence)
+bool
+System::add_DBus_lock_cmd(const char *dbus_name,
+                          const char *dbus_path,
+                          const char *dbus_interface,
+                          const char *dbus_lock_method,
+                          const char *dbus_method_to_check_existence)
 {
   TRACE_ENTER_MSG("System::add_DBus_lock_cmd", dbus_name);
 
   // I wish we could use std::move here
   IScreenLockMethod *lock_method = NULL;
-  lock_method = new ScreenLockDBus(session_connection,
-          dbus_name, dbus_path, dbus_interface,
-          dbus_lock_method, dbus_method_to_check_existence);
+  lock_method =
+    new ScreenLockDBus(session_connection, dbus_name, dbus_path, dbus_interface, dbus_lock_method, dbus_method_to_check_existence);
   if (!lock_method->is_lock_supported())
     {
       delete lock_method;
@@ -152,25 +153,18 @@ System::init_DBus_lock_commands()
       //      https://bugzilla.gnome.org/show_bug.cgi?id=689225
       //      (look for "unimplemented" in the patch), the lock method is still unipmlemented
       //    - therefore it is required to check the gnome API first.
-      //WORKS: Ubuntu 12.04: GNOME 3 fallback, Unity
-      add_DBus_lock_cmd(
-            "org.gnome.ScreenSaver", "/org/gnome/ScreenSaver", "org.gnome.ScreenSaver",
-            "Lock", "GetActive");
+      // WORKS: Ubuntu 12.04: GNOME 3 fallback, Unity
+      add_DBus_lock_cmd("org.gnome.ScreenSaver", "/org/gnome/ScreenSaver", "org.gnome.ScreenSaver", "Lock", "GetActive");
 
       //  Cinnamon:   https://github.com/linuxmint/cinnamon-screensaver/blob/master/doc/dbus-interface.html
       //    Same api as GNOME, but with different name,
-      add_DBus_lock_cmd(
-            "org.cinnamon.ScreenSaver", "/org/cinnamon/ScreenSaver", "org.cinnamon.ScreenSaver",
-            "Lock", "GetActive");
+      add_DBus_lock_cmd("org.cinnamon.ScreenSaver", "/org/cinnamon/ScreenSaver", "org.cinnamon.ScreenSaver", "Lock", "GetActive");
 
       //  Mate: https://github.com/mate-desktop/mate-screensaver/blob/master/doc/dbus-interface.xml
       //  Like GNOME
-      add_DBus_lock_cmd(
-                  "org.mate.ScreenSaver", "/org/mate/ScreenSaver", "org.mate.ScreenSaver",
-                  "Lock", "GetActive");
+      add_DBus_lock_cmd("org.mate.ScreenSaver", "/org/mate/ScreenSaver", "org.mate.ScreenSaver", "Lock", "GetActive");
 
-
-      //The FreeDesktop API - the most important and most widely supported
+      // The FreeDesktop API - the most important and most widely supported
       //    LXDE:  https://github.com/lxde/lxqt-powermanagement/blob/master/idleness/idlenesswatcherd.cpp
       //    KDE:
       //      https://projects.kde.org/projects/kde/kde-workspace/repository/revisions/master/entry/ksmserver/screenlocker/dbus/org.freedesktop.ScreenSaver.xml
@@ -189,38 +183,29 @@ System::init_DBus_lock_commands()
       //    the Lock method there is being removed (and not replaced with anything else).
       //    Probably the DEs will support these APIs in the future in order not to break other software.
 
-      //Is only partially implemented by GNOME, so GNOME has to go before
-      //Works correctly on KDE4 (Ubuntu 12.04)
-      add_DBus_lock_cmd(
-            "org.freedesktop.ScreenSaver", "/ScreenSaver", "org.freedesktop.ScreenSaver",
-            "Lock", "GetActive");
+      // Is only partially implemented by GNOME, so GNOME has to go before
+      // Works correctly on KDE4 (Ubuntu 12.04)
+      add_DBus_lock_cmd("org.freedesktop.ScreenSaver", "/ScreenSaver", "org.freedesktop.ScreenSaver", "Lock", "GetActive");
 
       //	KDE - old screensaver API - partially verified both
-      add_DBus_lock_cmd(
-                  "org.kde.screensaver", "/ScreenSaver", "org.freedesktop.ScreenSaver",
-                  "Lock", "GetActive");
-      add_DBus_lock_cmd(
-                  "org.kde.krunner", "/ScreenSaver", "org.freedesktop.ScreenSaver",
-                  "Lock", "GetActive");
+      add_DBus_lock_cmd("org.kde.screensaver", "/ScreenSaver", "org.freedesktop.ScreenSaver", "Lock", "GetActive");
+      add_DBus_lock_cmd("org.kde.krunner", "/ScreenSaver", "org.freedesktop.ScreenSaver", "Lock", "GetActive");
 
       //              - there some accounts that when org.freedesktop.ScreenSaver does not work, this works:
       //                      qdbus org.kde.ksmserver /ScreenSaver Lock
       //                      but it is probably a side effect of the fact that implementation of org.kde.ksmserver
       //                      is in the same process as of org.freedesktop.ScreenSaver
-      add_DBus_lock_cmd(
-                        "org.kde.ksmserver", "/ScreenSaver", "org.freedesktop.ScreenSaver",
-                        "Lock", "GetActive");
+      add_DBus_lock_cmd("org.kde.ksmserver", "/ScreenSaver", "org.freedesktop.ScreenSaver", "Lock", "GetActive");
 
       // EFL:
       add_DBus_lock_cmd(
-                  "org.enlightenment.wm.service", "/org/enlightenment/wm/RemoteObject", "org.enlightenment.wm.Desktop",
-                  "Lock", NULL);
+        "org.enlightenment.wm.service", "/org/enlightenment/wm/RemoteObject", "org.enlightenment.wm.Desktop", "Lock", NULL);
     }
   TRACE_EXIT();
 }
-#endif //HAVE_DBUS
+#  endif // HAVE_DBUS
 
-void 
+void
 System::add_cmdline_lock_cmd(const char *command_name, const char *parameters, bool async)
 {
   TRACE_ENTER_MSG("System::add_cmdline_lock_cmd", command_name);
@@ -239,11 +224,12 @@ System::add_cmdline_lock_cmd(const char *command_name, const char *parameters, b
     }
 }
 
-void System::init_cmdline_lock_commands(const char *display)
+void
+System::init_cmdline_lock_commands(const char *display)
 {
   TRACE_ENTER_MSG("System::init_cmdline_lock_commands", display);
 
-  //Works: XFCE, i3, LXDE
+  // Works: XFCE, i3, LXDE
   add_cmdline_lock_cmd("gnome-screensaver-command", "--lock", false);
   add_cmdline_lock_cmd("mate-screensaver-command", "--lock", false);
   add_cmdline_lock_cmd("enlightenment_remote", "-desktop-lock", false);
@@ -261,10 +247,9 @@ void System::init_cmdline_lock_commands(const char *display)
       add_cmdline_lock_cmd("xscreensaver-command", "-lock", false);
     }
 
-
-  //these two may call slock, which may be not user-friendly
-  //add_cmdline_lock_cmd("xflock4", NULL, true);
-  //add_cmdline_lock_cmd("lxlock", NULL, true);
+  // these two may call slock, which may be not user-friendly
+  // add_cmdline_lock_cmd("xflock4", NULL, true);
+  // add_cmdline_lock_cmd("lxlock", NULL, true);
 
   if (display != NULL)
     {
@@ -287,8 +272,7 @@ System::lock_screen()
 {
   TRACE_ENTER("System::lock");
 
-  for (std::vector<IScreenLockMethod *>::iterator iter = lock_commands.begin();
-      iter != lock_commands.end(); ++iter)
+  for (std::vector<IScreenLockMethod *>::iterator iter = lock_commands.begin(); iter != lock_commands.end(); ++iter)
     {
       if ((*iter)->lock())
         {
@@ -303,8 +287,8 @@ System::lock_screen()
 
 #if defined(PLATFORM_OS_UNIX) && defined(HAVE_DBUS)
 
-void System::add_DBus_system_state_command(
-      ISystemStateChangeMethod *method)
+void
+System::add_DBus_system_state_command(ISystemStateChangeMethod *method)
 {
   TRACE_ENTER("System::add_DBus_system_state_command");
 
@@ -323,25 +307,23 @@ void System::add_DBus_system_state_command(
   TRACE_EXIT();
 }
 
-void System::init_DBus_system_state_commands()
+void
+System::init_DBus_system_state_commands()
 {
   TRACE_ENTER("System::init_DBus_system_state_commands");
   if (system_connection)
     {
-      //These three DBus interfaces are too diverse
-      //to implement support for them in one class
-      //Logind is the future so it goes first
-      add_DBus_system_state_command(
-                          new SystemStateChangeLogind(system_connection));
+      // These three DBus interfaces are too diverse
+      // to implement support for them in one class
+      // Logind is the future so it goes first
+      add_DBus_system_state_command(new SystemStateChangeLogind(system_connection));
 
-      add_DBus_system_state_command(
-                          new SystemStateChangeUPower(system_connection));
+      add_DBus_system_state_command(new SystemStateChangeUPower(system_connection));
 
-      //ConsoleKit is deprecated so goes last
-      add_DBus_system_state_command(
-                          new SystemStateChangeConsolekit(system_connection));
+      // ConsoleKit is deprecated so goes last
+      add_DBus_system_state_command(new SystemStateChangeConsolekit(system_connection));
 
-      //Other interfaces:
+      // Other interfaces:
       //  GNOME:
       //    - there is GNOME Session API:
       //      https://git.gnome.org/browse/gnome-session/tree/gnome-session/org.gnome.SessionManager.xml
@@ -357,14 +339,15 @@ void System::init_DBus_system_state_commands()
       //        system("C:\\WINDOWS\\System32\\shutdown -s");
       //    win7
       //        system("C:\\WINDOWS\\System32\\shutdown /s");
-#undef ADD_DBUS_SERVICE
+#  undef ADD_DBUS_SERVICE
     }
   TRACE_EXIT();
 }
 
-#endif //PLATFORM_OS_UNIX
+#endif // PLATFORM_OS_UNIX
 
-bool System::execute(SystemOperation::SystemOperationType type)
+bool
+System::execute(SystemOperation::SystemOperationType type)
 {
   TRACE_ENTER("System::execute");
   if (type == SystemOperation::SYSTEM_OPERATION_NONE)
@@ -377,26 +360,27 @@ bool System::execute(SystemOperation::SystemOperationType type)
     }
   else
     {
-      for (std::vector<ISystemStateChangeMethod*>::iterator iter = system_state_commands.begin();
-                      iter != system_state_commands.end(); ++iter)
+      for (std::vector<ISystemStateChangeMethod *>::iterator iter = system_state_commands.begin();
+           iter != system_state_commands.end();
+           ++iter)
         {
           bool ret = false;
           switch (type)
             {
-              case SystemOperation::SYSTEM_OPERATION_SHUTDOWN:
-                ret = ((*iter)->shutdown());
-                break;
-              case SystemOperation::SYSTEM_OPERATION_SUSPEND:
-                ret = ((*iter)->suspend());
-                break;
-              case SystemOperation::SYSTEM_OPERATION_HIBERNATE:
-                ret = ((*iter)->hibernate());
-                break;
-              case SystemOperation::SYSTEM_OPERATION_SUSPEND_HYBRID:
-                ret = ((*iter)->suspendHybrid());
-                break;
-              default:
-                throw "System::execute: Unknown system operation";
+            case SystemOperation::SYSTEM_OPERATION_SHUTDOWN:
+              ret = ((*iter)->shutdown());
+              break;
+            case SystemOperation::SYSTEM_OPERATION_SUSPEND:
+              ret = ((*iter)->suspend());
+              break;
+            case SystemOperation::SYSTEM_OPERATION_HIBERNATE:
+              ret = ((*iter)->hibernate());
+              break;
+            case SystemOperation::SYSTEM_OPERATION_SUSPEND_HYBRID:
+              ret = ((*iter)->suspendHybrid());
+              break;
+            default:
+              throw "System::execute: Unknown system operation";
             };
           if (ret)
             {
@@ -412,21 +396,21 @@ bool System::execute(SystemOperation::SystemOperationType type)
 void
 System::init(
 #if defined(PLATFORM_OS_UNIX)
-             const char *display
+  const char *display
 #endif
-             )
+)
 {
   TRACE_ENTER("System::init");
 
 #if defined(PLATFORM_OS_UNIX)
-#if defined(HAVE_DBUS)
+#  if defined(HAVE_DBUS)
   init_DBus();
   init_DBus_lock_commands();
   init_DBus_system_state_commands();
-#endif
+#  endif
   init_cmdline_lock_commands(display);
 
-#elif defined(PLATFORM_OS_WIN32)
+#elif defined(PLATFORM_OS_WINDOWS)
   IScreenLockMethod *winLock = new W32LockScreen();
   if (winLock->is_lock_supported())
     {
@@ -448,36 +432,32 @@ System::init(
       delete winShut;
       winShut = NULL;
     }
-#endif //defined (PLATFORM_OS_WIN32)
+#endif // defined (PLATFORM_OS_WINDOWS)
 
   if (is_lockable())
     {
-      supported_system_operations.push_back(
-          SystemOperation("Lock", SystemOperation::SYSTEM_OPERATION_LOCK_SCREEN));
+      supported_system_operations.push_back(SystemOperation("Lock", SystemOperation::SYSTEM_OPERATION_LOCK_SCREEN));
     }
 
-  for (std::vector<ISystemStateChangeMethod*>::iterator iter = system_state_commands.begin();
-      iter != system_state_commands.end(); ++iter)
+  for (std::vector<ISystemStateChangeMethod *>::iterator iter = system_state_commands.begin(); iter != system_state_commands.end();
+       ++iter)
     {
       if ((*iter)->canShutdown())
         {
-          supported_system_operations.push_back(
-              SystemOperation("Shutdown", SystemOperation::SYSTEM_OPERATION_SHUTDOWN));
+          supported_system_operations.push_back(SystemOperation("Shutdown", SystemOperation::SYSTEM_OPERATION_SHUTDOWN));
         }
       if ((*iter)->canSuspend())
         {
-          supported_system_operations.push_back(
-              SystemOperation("Suspend", SystemOperation::SYSTEM_OPERATION_SUSPEND));
+          supported_system_operations.push_back(SystemOperation("Suspend", SystemOperation::SYSTEM_OPERATION_SUSPEND));
         }
       if ((*iter)->canHibernate())
         {
-          supported_system_operations.push_back(
-              SystemOperation("Hibernate", SystemOperation::SYSTEM_OPERATION_HIBERNATE));
+          supported_system_operations.push_back(SystemOperation("Hibernate", SystemOperation::SYSTEM_OPERATION_HIBERNATE));
         }
       if ((*iter)->canSuspendHybrid())
         {
           supported_system_operations.push_back(
-              SystemOperation("Suspend hybrid", SystemOperation::SYSTEM_OPERATION_SUSPEND_HYBRID));
+            SystemOperation("Suspend hybrid", SystemOperation::SYSTEM_OPERATION_SUSPEND_HYBRID));
         }
     }
 
@@ -489,25 +469,23 @@ System::init(
 void
 System::clear()
 {
-  for (std::vector<IScreenLockMethod *>::iterator iter = lock_commands.begin();
-        iter != lock_commands.end(); ++iter)
+  for (std::vector<IScreenLockMethod *>::iterator iter = lock_commands.begin(); iter != lock_commands.end(); ++iter)
     {
       delete *iter;
     }
   lock_commands.clear();
 
-  for (std::vector<ISystemStateChangeMethod*>::iterator iter = system_state_commands.begin();
-      iter != system_state_commands.end(); ++iter)
+  for (std::vector<ISystemStateChangeMethod *>::iterator iter = system_state_commands.begin(); iter != system_state_commands.end();
+       ++iter)
     {
       delete *iter;
     }
   system_state_commands.clear();
 
 #if defined(HAVE_DBUS)
-  //we shouldn't call g_dbus_connection_close_sync here:
-  //http://comments.gmane.org/gmane.comp.freedesktop.dbus/15286
+  // we shouldn't call g_dbus_connection_close_sync here:
+  // http://comments.gmane.org/gmane.comp.freedesktop.dbus/15286
   g_object_unref(session_connection);
   g_object_unref(session_connection);
 #endif
 }
-//TODO: lock before suspend/hibernate
