@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "debug.hh"
@@ -39,76 +39,16 @@
 #include "Exception.hh"
 #include "Util.hh"
 
-#define	SAMPLE_BITS		    (8)
-#define	WAVE_BUFFER_SIZE  (4096)
+#define SAMPLE_BITS (8)
+#define WAVE_BUFFER_SIZE (4096)
 
 using namespace workrave;
 
 static std::string sound_filename;
 
-static bool
-registry_get_value(const char *path, const char *name,
-                   char *out)
-{
-  HKEY handle;
-  bool rc = false;
-  LONG err;
-
-  err = RegOpenKeyEx(HKEY_CURRENT_USER, path, 0, KEY_ALL_ACCESS, &handle);
-  if (err == ERROR_SUCCESS)
-    {
-      DWORD type, size;
-      size = MAX_PATH;
-      err = RegQueryValueEx(handle, name, 0, &type, (LPBYTE) out, &size);
-      if (err == ERROR_SUCCESS)
-        {
-          rc = true;
-        }
-      RegCloseKey(handle);
-    }
-  return rc;
-}
-
-static bool
-registry_set_value(const char *path, const char *name,
-                   const char *value)
-{
-  HKEY handle;
-  bool rc = false;
-  DWORD disp;
-  LONG err;
-
-  err = RegCreateKeyEx(HKEY_CURRENT_USER, path, 0,
-                       "", REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS,
-                       NULL, &handle, &disp);
-  if (err == ERROR_SUCCESS)
-    {
-      err = RegSetValueEx(handle, name, 0, REG_SZ, (BYTE *) value,
-                          strlen(value)+1);
-      RegCloseKey(handle);
-      rc = (err == ERROR_SUCCESS);
-    }
-  return rc;
-}
-
-
-
-W32SoundPlayer::W32SoundPlayer()
-{
-}
-
-W32SoundPlayer::~W32SoundPlayer()
-{
-}
-
-
-void
-W32SoundPlayer::play_sound(SoundEvent snd )
-{
-  TRACE_ENTER_MSG( "W32SoundPlayer::play_sound", SoundPlayer::sound_registry[snd].friendly_name );
-  TRACE_EXIT();
-}
+W32SoundPlayer::W32SoundPlayer() {}
 
+W32SoundPlayer::~W32SoundPlayer() {}
 
 bool
 W32SoundPlayer::capability(SoundCapability cap)
@@ -133,7 +73,7 @@ redistribute under GNU terms.
 void
 W32SoundPlayer::play_sound(string wavfile)
 {
-  TRACE_ENTER_MSG( "W32SoundPlayer::play_sound", wavfile);
+  TRACE_ENTER_MSG("W32SoundPlayer::play_sound", wavfile);
 
   if (sound_filename != "")
     {
@@ -149,122 +89,17 @@ W32SoundPlayer::play_sound(string wavfile)
   TRACE_EXIT();
 }
 
-
-bool
-W32SoundPlayer::get_sound_enabled(SoundEvent snd, bool &enabled)
-{
-  char key[MAX_PATH], val[MAX_PATH];
-
-  strcpy(key, "AppEvents\\Schemes\\Apps\\Workrave\\");
-  strcat(key, SoundPlayer::sound_registry[snd].label);
-  strcat(key, "\\.current");
-
-  if (registry_get_value(key, NULL, val))
-    {
-      enabled = (val[0] != '\0');
-    }
-
-  return true;
-}
-
-
-void
-W32SoundPlayer::set_sound_enabled(SoundEvent snd, bool enabled)
-{
-  if (enabled)
-    {
-      char key[MAX_PATH], def[MAX_PATH];
-
-      strcpy(key, "AppEvents\\Schemes\\Apps\\Workrave\\");
-      strcat(key, SoundPlayer::sound_registry[snd].label);
-      strcat(key, "\\.default");
-
-      if (registry_get_value(key, NULL, def))
-        {
-          char *defkey = strrchr(key, '.');
-          strcpy(defkey, ".current");
-          registry_set_value(key, NULL, def);
-        }
-    }
-  else
-    {
-      char key[MAX_PATH];
-
-      strcpy(key, "AppEvents\\Schemes\\Apps\\Workrave\\");
-      strcat(key, SoundPlayer::sound_registry[snd].label);
-      strcat(key, "\\.current");
-
-      registry_set_value(key, NULL, "");
-    }
-}
-
-
-bool
-W32SoundPlayer::get_sound_wav_file(SoundEvent snd, std::string &wav_file)
-{
-  char key[MAX_PATH], val[MAX_PATH];
-
-  strcpy(key, "AppEvents\\Schemes\\Apps\\Workrave\\");
-  strcat(key, SoundPlayer::sound_registry[snd].label);
-  strcat(key, "\\.current");
-
-  if (registry_get_value(key, NULL, val))
-    {
-      wav_file = val;
-    }
-
-  if (wav_file == "")
-    {
-      char *cur = strrchr(key, '.');
-      strcpy(cur, ".default");
-      if (registry_get_value(key, NULL, val))
-        {
-          wav_file = val;
-        }
-    }
-
-  return true;
-}
-
-void
-W32SoundPlayer::set_sound_wav_file(SoundEvent snd, const std::string &wav_file)
-{
-  char key[MAX_PATH], val[MAX_PATH];
-
-  strcpy(key, "AppEvents\\EventLabels\\");
-  strcat(key, SoundPlayer::sound_registry[snd].label);
-  if (! registry_get_value(key, NULL, val))
-    {
-      registry_set_value(key, NULL, SoundPlayer::sound_registry[snd].friendly_name);
-    }
-
-  strcpy(key, "AppEvents\\Schemes\\Apps\\Workrave\\");
-  strcat(key, SoundPlayer::sound_registry[snd].label);
-  strcat(key, "\\.default");
-  registry_set_value(key, NULL, wav_file.c_str());
-
-  bool enabled = false;
-  bool valid = get_sound_enabled(snd, enabled);
-
-  if (!valid || enabled)
-    {
-      char *def = strrchr(key, '.');
-      strcpy(def, ".current");
-      registry_set_value(key, NULL, wav_file.c_str());
-    }
-}
-
-
 DWORD WINAPI
 W32SoundPlayer::thread_Play(LPVOID lpParam)
 {
-  W32SoundPlayer *pThis = (W32SoundPlayer *) lpParam;
+  W32SoundPlayer *pThis = (W32SoundPlayer *)lpParam;
   pThis->Play();
 
-  return (DWORD) 0;
+  return (DWORD)0;
 }
 
-void W32SoundPlayer::Play()
+void
+W32SoundPlayer::Play()
 {
   TRACE_ENTER("W32SoundPlayer::Play");
 
@@ -275,11 +110,11 @@ void W32SoundPlayer::Play()
       write(sample, sample_size);
       close();
     }
-  catch(Exception e)
+  catch (Exception e)
     {
       TRACE_MSG(e.details());
     }
-  catch(...)
+  catch (...)
     {
     }
 
@@ -288,7 +123,6 @@ void W32SoundPlayer::Play()
   TRACE_EXIT();
 }
 
-
 void
 W32SoundPlayer::open()
 {
@@ -297,11 +131,10 @@ W32SoundPlayer::open()
 
   wave_event = CreateEvent(NULL, FALSE, FALSE, NULL);
 
-  number_of_buffers          = 16;
-  buffer_position            = 0;
+  number_of_buffers = 16;
+  buffer_position = 0;
 
-  res = waveOutOpen(&waveout, WAVE_MAPPER, &format,
-                    (DWORD) wave_event, (DWORD) 0,CALLBACK_EVENT);
+  res = waveOutOpen(&waveout, WAVE_MAPPER, &format, (DWORD)wave_event, (DWORD)0, CALLBACK_EVENT);
   if (res != MMSYSERR_NOERROR)
     {
       throw Exception("waveOutOpen");
@@ -325,10 +158,10 @@ W32SoundPlayer::open()
       throw Exception("waveOutSetVolume");
     }
 
-  buffers = (WAVEHDR**) malloc(number_of_buffers * sizeof(WAVEHDR**));
+  buffers = (WAVEHDR **)malloc(number_of_buffers * sizeof(WAVEHDR **));
   for (i = 0; i < number_of_buffers; i++)
     {
-      buffers[i] = (WAVEHDR*) calloc(1, sizeof(WAVEHDR));
+      buffers[i] = (WAVEHDR *)calloc(1, sizeof(WAVEHDR));
       if (buffers[i] == NULL)
         {
           throw Exception("buffers malloc");
@@ -345,15 +178,14 @@ W32SoundPlayer::open()
     }
 }
 
-
 int
 W32SoundPlayer::write(unsigned char *buf, size_t size)
 {
-	unsigned char *ptr = buf;
-	unsigned char *end = buf + size;
-	MMRESULT res;
+  unsigned char *ptr = buf;
+  unsigned char *end = buf + size;
+  MMRESULT res;
 
-	for (int i = buffer_position; ptr < end; i = (i + 1) % number_of_buffers)
+  for (int i = buffer_position; ptr < end; i = (i + 1) % number_of_buffers)
     {
       while ((buffers[i]->dwFlags & WHDR_INQUEUE) != 0)
         {
@@ -383,7 +215,7 @@ W32SoundPlayer::write(unsigned char *buf, size_t size)
         }
     }
 
-	return ptr - buf;
+  return ptr - buf;
 }
 
 void
@@ -411,7 +243,6 @@ W32SoundPlayer::flush_buffer(int i)
     }
 }
 
-
 void
 W32SoundPlayer::close(void)
 {
@@ -461,7 +292,7 @@ W32SoundPlayer::load_wav_file(const string &filename)
 {
   MMRESULT res;
 
-  HMMIO handle = mmioOpen((CHAR*)filename.c_str(), NULL, MMIO_ALLOCBUF | MMIO_READ);
+  HMMIO handle = mmioOpen((CHAR *)filename.c_str(), NULL, MMIO_ALLOCBUF | MMIO_READ);
   if (handle == NULL)
     {
       throw Exception("mmioOpen");
@@ -476,12 +307,11 @@ W32SoundPlayer::load_wav_file(const string &filename)
       throw Exception("mmioDescend");
     }
 
-  if (parent.ckid != FOURCC_RIFF || parent.fccType != mmioFOURCC('W', 'A', 'V', 'E' ))
+  if (parent.ckid != FOURCC_RIFF || parent.fccType != mmioFOURCC('W', 'A', 'V', 'E'))
     {
       throw Exception("no Wave");
     }
 
-
   MMCKINFO child;
   memset((void *)&child, 0, sizeof(child));
 
@@ -503,13 +333,11 @@ W32SoundPlayer::load_wav_file(const string &filename)
       throw Exception("format size");
     }
 
-
   if (format.wFormatTag != WAVE_FORMAT_PCM)
     {
       throw Exception("format supported");
     }
 
-
   res = mmioAscend(handle, &child, 0);
   if (res != MMSYSERR_NOERROR)
     {
@@ -539,7 +367,6 @@ W32SoundPlayer::load_wav_file(const string &filename)
       throw Exception("mmioAscend");
     }
 
-
   int pos = 0;
   do
     {
@@ -557,10 +384,8 @@ W32SoundPlayer::load_wav_file(const string &filename)
         }
 
       mmio.pchNext = mmio.pchEndRead;
-
-    } while (pos < (int)sample_size && mmioAdvance(handle, &mmio, MMIO_READ) == 0);
-
+    }
+  while (pos < (int)sample_size && mmioAdvance(handle, &mmio, MMIO_READ) == 0);
 
   mmioClose(handle, 0);
 }
-
