@@ -20,7 +20,7 @@
 #include "preinclude.h"
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "debug.hh"
@@ -30,12 +30,8 @@
 #include "TimerBoxControl.hh"
 
 AppletWindow::AppletWindow()
-  : timer_box_view(0),
-    timer_box_control(0)
-{
-}
-
-AppletWindow::~AppletWindow()
+  : timer_box_view(nullptr)
+  , timer_box_control(nullptr)
 {
 }
 
@@ -64,14 +60,8 @@ AppletWindow::init_applet()
 {
 }
 
-sigc::signal<void, IAppletWindow::AppletState> &
-AppletWindow::signal_state_changed()
+sigc::signal<void, bool> &
+AppletWindow::signal_visibility_changed()
 {
-  return state_changed_signal;
-}
-
-sigc::signal<void> &
-AppletWindow::signal_request_activate()
-{
-  return request_activate_signal;
+  return visibility_changed_signal;
 }
