@@ -201,7 +201,18 @@ GUI::main()
 #ifdef HAVE_GTK3
   app = Gtk::Application::create(argc, argv, "org.workrave.WorkraveApplication");
   app->hold();
-#else
+#endif
+
+  init_core();
+
+#if defined(PLATFORM_OS_UNIX)
+  if (GUIConfig::get_force_x11_enabled())
+    {
+      g_setenv("GDK_BACKEND", "x11", TRUE);
+    }
+#endif
+
+#ifndef HAVE_GTK3
 #  if defined(PLATFORM_OS_WINDOWS)
   Glib::OptionContext option_ctx;
   Glib::OptionGroup *option_group = new Glib::OptionGroup(egg_sm_client_get_option_group());
@@ -224,7 +235,6 @@ GUI::main()
     }
 #endif
 
-  init_core();
   init_nls();
   init_debug();
   init_sound_player();
